Module proxy

Module proxy 

Structs

ProxyServer

Enums

ByteLimitResult
Result of applying byte limit check to a request

Constants

BLOCKED_MESSAGE
HTTPJAIL_HEADER
HTTPJAIL_HEADER_VALUE

Functions

apply_request_byte_limit
Applies a byte limit to an outgoing request by wrapping its body.
create_connect_403_response
Create a raw HTTP/1.1 403 Forbidden response for CONNECT tunnels
create_connect_403_response_with_context
Create a raw HTTP/1.1 403 Forbidden response for CONNECT tunnels with context
create_error_response
create_forbidden_response
Create a 403 Forbidden error response with optional context
get_client
Get or create the shared HTTP/HTTPS client
handle_http_request
init_client_with_ca
Initialize the HTTP client with the httpjail CA certificate
prepare_upstream_request
Prepare a request for forwarding to upstream server Removes proxy-specific headers and converts body to BoxBody