Structs
Enums
- Byte
Limit Result - Result of applying byte limit check to a request
Constants
Functions
- apply_
request_ byte_ limit - Applies a byte limit to an outgoing request by wrapping its body.
- create_
connect_ 403_ response - Create a raw HTTP/1.1 403 Forbidden response for CONNECT tunnels
- create_
connect_ 403_ response_ with_ context - Create a raw HTTP/1.1 403 Forbidden response for CONNECT tunnels with context
- create_
error_ response - create_
forbidden_ response - Create a 403 Forbidden error response with optional context
- get_
client - Get or create the shared HTTP/HTTPS client
- handle_
http_ request - init_
client_ with_ ca - Initialize the HTTP client with the httpjail CA certificate
- prepare_
upstream_ request - Prepare a request for forwarding to upstream server Removes proxy-specific headers and converts body to BoxBody